'use strict';

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

Object.defineProperty(exports, "__esModule", {
    value: true
});

exports.default = function (patterns, outRootDir, options) {
    return function babelBuild(resolve, reject) {
        process.env.NODE_ENV = 'production';

        var path = require('path');
        var globby = require('globby');
        var pify = require('pify');
        var makeDir = pify(require('mkdirp'));
        var transformFile = pify(require('babel-core').transformFile);
        var writeFile = pify(require('fs').writeFile);

        globby(patterns, { realpath: true }).then(function (files) {
            return _promise2.default.all(files.map(function (inFile) {
                // /root/src/beep/index.js -> src/beep/index.js
                var relativeInDir = path.relative(process.cwd(), inFile);
                // src/beep/index.js -> beep/index.js
                var relativeInFile = relativeInDir.split(path.sep).slice(1).join(path.sep);
                // beep/index.js -> build/beep/index.js
                var outFile = path.resolve(outRootDir, relativeInFile);
                // build/beep/index.js -> build/beep
                var outDir = path.dirname(outFile);

                return makeDir(outDir).then(function () {
                    return transformFile(inFile, options);
                }).then(function (result) {
                    return writeFile(outFile, result.code, 'utf-8');
                }).then(function () {
                    return outFile;
                });
            }));
        }).then(resolve).catch(reject);
    };
};

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

module.exports = exports['default'];